@@ -297,6 +297,7 @@ class RockstarHaloFinder(ParallelAnalysisInterface):
         if self.workgroup.name != "readers":
             return None
         tds = ts[0]
+        tds.index
         ptype = self.particle_type
         if ptype not in tds.particle_types and ptype != "all":
             has_particle_filter = tds.add_particle_filter(ptype)
@@ -394,7 +395,7 @@ class RockstarHaloFinder(ParallelAnalysisInterface):
             self.server_address,
             self.port,
             num_outputs,
-            self.total_particles,
+            np.int64(self.total_particles),
             self.particle_type,
             self.mass_field,
             star_types=self.star_types,
